@@ -12,7 +12,8 @@ class Automation:
         'next_process_on': None,     # string - If trigger is `daily`, date this automation will next run.
         'schedule': None,     # object - If trigger is `custom_schedule`, Custom schedule description for when the automation should be run.
         'source': None,     # string - Source Path
-        'destination': None,     # string - Destination Path
+        'destination': None,     # string - DEPRECATED: Destination Path
+        'destinations': None,     # string - Destination Path
         'destination_replace_from': None,     # string - If set, this string in the destination path will be replaced with the value in `destination_replace_to`.
         'destination_replace_to': None,     # string - If set, this string will replace the value `destination_replace_from` in the destination filename. You can use special patterns here.
         'path': None,     # string - Path on which this Automation runs.  Supports globs. This must be slash-delimited, but it must neither start nor end with a slash. Maximum of 5000 characters.
@@ -43,7 +44,8 @@ class Automation:
     # Parameters:
     #   automation (required) - string - Automation type
     #   source - string - Source Path
-    #   destination - string - Destination Path
+    #   destination - string - DEPRECATED: Destination Path
+    #   destinations - array(string) - A list of String destination paths or Hash of folder_path and optional file_path.
     #   destination_replace_from - string - If set, this string in the destination path will be replaced with the value in `destination_replace_to`.
     #   destination_replace_to - string - If set, this string will replace the value `destination_replace_from` in the destination filename. You can use special patterns here.
     #   interval - string - How often to run this automation? One of: `day`, `week`, `week_end`, `month`, `month_end`, `quarter`, `quarter_end`, `year`, `year_end`
@@ -75,6 +77,8 @@ class Automation:
             raise InvalidParameterError("Bad parameter: source must be an str")
         if "destination" in params and not isinstance(params["destination"], str):
             raise InvalidParameterError("Bad parameter: destination must be an str")
+        if "destinations" in params and not isinstance(params["destinations"], list):
+            raise InvalidParameterError("Bad parameter: destinations must be an list")
         if "destination_replace_from" in params and not isinstance(params["destination_replace_from"], str):
             raise InvalidParameterError("Bad parameter: destination_replace_from must be an str")
         if "destination_replace_to" in params and not isinstance(params["destination_replace_to"], str):
@@ -183,7 +187,8 @@ def get(id, params = None, options = None):
 # Parameters:
 #   automation (required) - string - Automation type
 #   source - string - Source Path
-#   destination - string - Destination Path
+#   destination - string - DEPRECATED: Destination Path
+#   destinations - array(string) - A list of String destination paths or Hash of folder_path and optional file_path.
 #   destination_replace_from - string - If set, this string in the destination path will be replaced with the value in `destination_replace_to`.
 #   destination_replace_to - string - If set, this string will replace the value `destination_replace_from` in the destination filename. You can use special patterns here.
 #   interval - string - How often to run this automation? One of: `day`, `week`, `week_end`, `month`, `month_end`, `quarter`, `quarter_end`, `year`, `year_end`
@@ -206,6 +211,8 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: source must be an str")
     if "destination" in params and not isinstance(params["destination"], str):
         raise InvalidParameterError("Bad parameter: destination must be an str")
+    if "destinations" in params and not isinstance(params["destinations"], list):
+        raise InvalidParameterError("Bad parameter: destinations must be an list")
     if "destination_replace_from" in params and not isinstance(params["destination_replace_from"], str):
         raise InvalidParameterError("Bad parameter: destination_replace_from must be an str")
     if "destination_replace_to" in params and not isinstance(params["destination_replace_to"], str):
@@ -236,7 +243,8 @@ def create(params = None, options = None):
 # Parameters:
 #   automation (required) - string - Automation type
 #   source - string - Source Path
-#   destination - string - Destination Path
+#   destination - string - DEPRECATED: Destination Path
+#   destinations - array(string) - A list of String destination paths or Hash of folder_path and optional file_path.
 #   destination_replace_from - string - If set, this string in the destination path will be replaced with the value in `destination_replace_to`.
 #   destination_replace_to - string - If set, this string will replace the value `destination_replace_from` in the destination filename. You can use special patterns here.
 #   interval - string - How often to run this automation? One of: `day`, `week`, `week_end`, `month`, `month_end`, `quarter`, `quarter_end`, `year`, `year_end`
@@ -262,6 +270,8 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: source must be an str")
     if "destination" in params and not isinstance(params["destination"], str):
         raise InvalidParameterError("Bad parameter: destination must be an str")
+    if "destinations" in params and not isinstance(params["destinations"], list):
+        raise InvalidParameterError("Bad parameter: destinations must be an list")
     if "destination_replace_from" in params and not isinstance(params["destination_replace_from"], str):
         raise InvalidParameterError("Bad parameter: destination_replace_from must be an str")
     if "destination_replace_to" in params and not isinstance(params["destination_replace_to"], str):
